==> jaguar_session-0.3.0.tar.gz: example/directly/server/server.dart <==
library example.basic_auth.server;

import 'dart:async';
import 'dart:convert';

import 'package:jaguar/jaguar.dart';
import 'package:jaguar_session/jaguar_session.dart';

import '../../common/models/book/book.dart';
import '../../common/books.dart';

part 'server.g.dart';

/// This route group contains login and logout authentication routes
@RouteGroup()
class AuthRoutes extends _$JaguarAuthRoutes {
  @Post(path: '/login/:username/:pwd')
  Future<Response> login(Request req, String username, String pwd) async {
    if (username == null || pwd == null) {
      throw new UnAuthorizedError();
    }

    if (username != 'jaguar' || pwd != 'awesome') {
      throw new UnAuthorizedError();
    }

    Response resp = new Response(null, statusCode: 200);
    CookieSessionManager sesMan = sessionManager();
    //Set session information
    await sesMan.updateSession({'username': 'jaguar'});
    //Update response with session information
    return await sesMan.updateResponse(req, resp);
  }

  @Post(path: '/logout')
  Future<Response> logout(Request req) async {
    Response resp = new Response(null, statusCode: 200);
    CookieSessionManager sesMan = sessionManager();
    //Clear session information on logout
    await sesMan.clearSession();
    //Update response
    return await sesMan.updateResponse(req, resp);
  }

  CookieSessionManager sessionManager() => new CookieSessionManager();
}

/// Collection of routes that need authorization
@RouteGroup(path: '/book')
class StudentRoutes extends _$JaguarStudentRoutes implements RequestHandler {
  @Get(path: '/all')
  Future<Response<String>> getAllBooks(Request req) async {
    CookieSessionManager sesMan = sessionManager();
    //Parse session information
    await sesMan.parseRequest(req);

    //Authorize
    String username = sesMan.getInValue('username');
    if (username is! String || username != 'jaguar') {
      throw new UnAuthorizedError();
    }

    List<Map> ret = books.values.map((Book book) => book.toMap()).toList();
    Response<String> resp = new Response<String>(JSON.encode(ret));
    return resp;
  }

  CookieSessionManager sessionManager() => new CookieSessionManager();
}

@Api(path: '/api')
class LibraryApi extends Object
    with _$JaguarLibraryApi
    implements RequestHandler {
  @Group()
  final AuthRoutes auth = new AuthRoutes();

  @Group()
  final StudentRoutes student = new StudentRoutes();
}

server() async {
  LibraryApi api = new LibraryApi();

  Configuration configuration = new Configuration();
  configuration.addApi(api);

  await serve(configuration);
}

==> jaguar_session-0.3.1.tar.gz: example/directly/server/server.dart <==
library example.basic_auth.server;

import 'dart:async';
import 'dart:convert';

import 'package:jaguar/jaguar.dart';
import 'package:jaguar_session/jaguar_session.dart';

import '../../common/models/book/book.dart';
import '../../common/books.dart';

part 'server.g.dart';

/// This route group contains login and logout authentication routes
@RouteGroup()
class AuthRoutes {
  @Post(path: '/login/:username/:pwd')
  Future<Response> login(Request req, String username, String pwd) async {
    if (username == null || pwd == null) {
      throw new UnAuthorizedError();
    }

    if (username != 'jaguar' || pwd != 'awesome') {
      throw new UnAuthorizedError();
    }

    Response resp = new Response(null, statusCode: 200);
    CookieSessionManager sesMan = sessionManager();
    //Set session information
    await sesMan.updateSession({'username': 'jaguar'});
    //Update response with session information
    return await sesMan.updateResponse(req, resp);
  }

  @Post(path: '/logout')
  Future<Response> logout(Request req) async {
    Response resp = new Response(null, statusCode: 200);
    CookieSessionManager sesMan = sessionManager();
    //Clear session information on logout
    await sesMan.clearSession();
    //Update response
    return await sesMan.updateResponse(req, resp);
  }

  CookieSessionManager sessionManager() => new CookieSessionManager();
}

/// Collection of routes that need authorization
@RouteGroup(path: '/book')
class StudentRoutes {
  @Get(path: '/all')
  Future<Response<String>> getAllBooks(Request req) async {
    CookieSessionManager sesMan = sessionManager();
    //Parse session information
    await sesMan.parseRequest(req);

    //Authorize
    String username = sesMan.getInValue('username');
    if (username is! String || username != 'jaguar') {
      throw new UnAuthorizedError();
    }

    List<Map> ret = books.values.map((Book book) => book.toMap()).toList();
    Response<String> resp = new Response<String>(JSON.encode(ret));
    return resp;
  }

  CookieSessionManager sessionManager() => new CookieSessionManager();
}

@Api(path: '/api')
class LibraryApi {
  @Group()
  final AuthRoutes auth = new AuthRoutes();

  @Group()
  final StudentRoutes student = new StudentRoutes();
}

server() async {
  final api = new JaguarLibraryApi();

  Configuration configuration = new Configuration();
  configuration.addApi(api);

  await serve(configuration);
}
